/* Wikipedia Popup */
.wiki-popup {
  display: none;
  position: absolute;
  background-color: var(--md-default-bg-color);
  color: var(--md-typeset-color);
  border: 1px solid #ccc;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
  font-size: 1.3em;
  z-index: 1000;
  max-width: 400px;
}

.wiki-popup-container {
  padding: 10px;
}

.wiki-popup img {
  display: block;
  width: 100%;
  max-height: 300px;
  object-fit: cover;
  overflow: hidden;
}